from tests.test_interface import TestInterface
from tests.test_timequeue import TestTimeQueue
from tests.test_pubsub import TestConsumer, TestProcessConsumer, TestProducer
from tests.test_simulation import TestDSSchedulable, TestException, TestSim
from tests.test_queue import TestQueue
from tests.test_event import TestEvent
import unittest

if __name__ == '__main__':
    unittest.main()
